@@ -1,12 +1,8 @@
-from PyObjCTools.TestSupport import *
-from Quartz.CoreGraphics import *
+from PyObjCTools.TestSupport import TestCase, expectedFailure
+import Quartz  # noqa: F401
 
 
 class TestCGPSConverter(TestCase):
     @expectedFailure
     def testIncomplete(self):
         self.fail("Add header tests for <CoreGraphics/CGPSConverter.h>")
-
-
-if __name__ == "__main__":
-    main()
